@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -42,10 +42,6 @@ GravatarDownloadPixmapWidget::GravatarDownloadPixmapWidget(QWidget *parent)
     connect(mLineEdit, &QLineEdit::textChanged, this, &GravatarDownloadPixmapWidget::slotTextChanged);
     hbox->addWidget(mLineEdit);
 
-    mUseHttps = new QCheckBox(i18n("Use HTTPS Protocol"));
-    mUseHttps->setObjectName(QStringLiteral("usehttps"));
-    mainLayout->addWidget(mUseHttps);
-
     mUseLibravatar = new QCheckBox(i18n("Use Libravatar"));
     mUseLibravatar->setObjectName(QStringLiteral("uselibravatar"));
     mainLayout->addWidget(mUseLibravatar);
@@ -100,7 +96,6 @@ void GravatarDownloadPixmapWidget::slotSearchButton()
     //job->setUseDefaultPixmap(true);
     job->setUseLibravatar(mUseLibravatar->isChecked());
     job->setFallbackGravatar(mFallbackGravatar->isChecked());
-    job->setUseHttps(mUseHttps->isChecked());
     //qDebug() << job->generateGravatarUrl(false);
     if (job->canStart()) {
         connect(job, &GravatarResolvUrlJob::finished, this, &GravatarDownloadPixmapWidget::slotResolvUrlFinish);
